TriggersTweak

Struct TriggersTweak 

pub struct TriggersTweak {}

Implementations

Source

impl TriggersTweak

pub fn push(scenario: &mut Scenario, trigger: Token) -> Result<(), String>

Push the given trigger to the end of the trigger data This method will check the correctness and version compatible.

Examples
use aoe2_probe::{Scenario, TriggersTweak};
use aoe2_probe::prebuilt::ver1_46::Trigger;

let mut scenario = Scenario::from_file("./resources/chapter_1.aoe2scenario").unwrap();
let trigger = Trigger::default();

TriggersTweak::push(&mut scenario, trigger).unwrap();
pub fn insert( scenario: &mut Scenario, trigger: Token, display_index: usize, execute_index: usize, ) -> Result<(), String>

pub fn sort_by_display_order(scenario: &mut Scenario) -> Result<(), String>

Sort the trigger data by the display order This method will check the correctness and version compatible.

Examples
use aoe2_probe::{Scenario, TriggersTweak};
use aoe2_probe::prebuilt::ver1_46::Trigger;

let mut scenario = Scenario::from_file("./resources/chapter_1.aoe2scenario").unwrap();

TriggersTweak::sort_by_display_order(&mut scenario).unwrap();